@@ -207,6 +207,7 @@ type inspect = {
   i_product_name : string;
   i_product_variant : string;
   i_mountpoints : (string * string) list;
+  i_filesystems : filesystem list;
   i_apps : Guestfs.application2 list;   (** List of packages installed. *)
   i_apps_map : Guestfs.application2 list StringMap.t;
     (** This is a map from the app name to the application object.
@@ -220,6 +221,14 @@ type inspect = {
   i_drive_mappings : (string * string) list;
 }
 
+and filesystem = {
+  fs_dev : string;
+  fs_type : string option;
+  fs_version : string option;
+  fs_label : string option;
+  fs_uuid : string option;
+}
+
 val string_of_inspect : inspect -> string
 
 (** {2 Disk stats} *)
